@@ -631,22 +631,22 @@ class ER:
                 return True
             
             if thisValue != otherValue:
-                if debugging: print(f"direct property match {key} fail {thisValue} vs {otherValue}")
+                #if debugging: print(f"direct property match {key} fail {thisValue} vs {otherValue}")
                 check = False
                 if key == "relationFrom":
                     check = (thisNode.get("relationFrom", "") == otherNode.get("relationTo", ""))
-                    if debugging: print(f'({thisNode.get("relationFrom", "")} == {otherNode.get("relationTo", "")})?')
+                    #if debugging: print(f'({thisNode.get("relationFrom", "")} == {otherNode.get("relationTo", "")})?')
                 if key == "relationTo":
                     check = (thisNode.get("relationTo", "") == otherNode.get("relationFrom", ""))
-                    if debugging: print(f'({thisNode.get("relationTo", "")} == {otherNode.get("relationFrom", "")})?')
+                    #if debugging: print(f'({thisNode.get("relationTo", "")} == {otherNode.get("relationFrom", "")})?')
                 if key == "fromEdgeLabel":
                     check = (thisNode.get("fromEdgeLabel", "") == otherNode.get("toEdgeLabel", ""))
-                    if debugging: print(f'({thisNode.get("fromEdgeLabel", "")} == {otherNode.get("toEdgeLabel", "")})?')
+                    #if debugging: print(f'({thisNode.get("fromEdgeLabel", "")} == {otherNode.get("toEdgeLabel", "")})?')
                 if key == "toEdgeLabel":
                     check = (thisNode.get("toEdgeLabel", "") == otherNode.get("fromEdgeLabel", ""))
-                    if debugging: print(f'({thisNode.get("toEdgeLabel", "")} == {otherNode.get("fromEdgeLabel", "")})?')
+                    #if debugging: print(f'({thisNode.get("toEdgeLabel", "")} == {otherNode.get("fromEdgeLabel", "")})?')
                 if not check:
-                    if debugging: print(f"inverse property compare {key} fail {thisValue} vs {otherValue}")
+                    #if debugging: print(f"inverse property compare {key} fail {thisValue} vs {otherValue}")
                     return False
                 else:
                     return True
